==> android-2.3.3-sources.jar: android/os/Build.java <==
package android.os;
public class Build
{
public static class VERSION
{
public  VERSION() { throw new RuntimeException("Stub!"); }
public static final java.lang.String INCREMENTAL;
public static final java.lang.String RELEASE;
public static final java.lang.String SDK;
public static final int SDK_INT;
public static final java.lang.String CODENAME;
static { INCREMENTAL = null; RELEASE = null; SDK = null; SDK_INT = 0; CODENAME = null; }
}
public static class VERSION_CODES
{
public  VERSION_CODES() { throw new RuntimeException("Stub!"); }
public static final int CUR_DEVELOPMENT = 10000;
public static final int BASE = 1;
public static final int BASE_1_1 = 2;
public static final int CUPCAKE = 3;
public static final int DONUT = 4;
public static final int ECLAIR = 5;
public static final int ECLAIR_0_1 = 6;
public static final int ECLAIR_MR1 = 7;
public static final int FROYO = 8;
public static final int GINGERBREAD = 9;
public static final int GINGERBREAD_MR1 = 10;
}
public  Build() { throw new RuntimeException("Stub!"); }
public static final java.lang.String UNKNOWN = "unknown";
public static final java.lang.String ID;
public static final java.lang.String DISPLAY;
public static final java.lang.String PRODUCT;
public static final java.lang.String DEVICE;
public static final java.lang.String BOARD;
public static final java.lang.String CPU_ABI;
public static final java.lang.String CPU_ABI2;
public static final java.lang.String MANUFACTURER;
public static final java.lang.String BRAND;
public static final java.lang.String MODEL;
public static final java.lang.String BOOTLOADER;
public static final java.lang.String RADIO;
public static final java.lang.String HARDWARE;
public static final java.lang.String SERIAL;
public static final java.lang.String TYPE;
public static final java.lang.String TAGS;
public static final java.lang.String FINGERPRINT;
public static final long TIME;
public static final java.lang.String USER;
public static final java.lang.String HOST;
static { ID = null; DISPLAY = null; PRODUCT = null; DEVICE = null; BOARD = null; CPU_ABI = null; CPU_ABI2 = null; MANUFACTURER = null; BRAND = null; MODEL = null; BOOTLOADER = null; RADIO = null; HARDWARE = null; SERIAL = null; TYPE = null; TAGS = null; FINGERPRINT = null; TIME = 0; USER = null; HOST = null; }
}

==> android-4.0.1.2-sources.jar: android/os/Build.java <==
package android.os;
public class Build
{
public static class VERSION
{
public  VERSION() { throw new RuntimeException("Stub!"); }
public static final java.lang.String INCREMENTAL;
public static final java.lang.String RELEASE;
public static final java.lang.String SDK;
public static final int SDK_INT;
public static final java.lang.String CODENAME;
static { INCREMENTAL = null; RELEASE = null; SDK = null; SDK_INT = 0; CODENAME = null; }
}
public static class VERSION_CODES
{
public  VERSION_CODES() { throw new RuntimeException("Stub!"); }
public static final int CUR_DEVELOPMENT = 10000;
public static final int BASE = 1;
public static final int BASE_1_1 = 2;
public static final int CUPCAKE = 3;
public static final int DONUT = 4;
public static final int ECLAIR = 5;
public static final int ECLAIR_0_1 = 6;
public static final int ECLAIR_MR1 = 7;
public static final int FROYO = 8;
public static final int GINGERBREAD = 9;
public static final int GINGERBREAD_MR1 = 10;
public static final int HONEYCOMB = 11;
public static final int HONEYCOMB_MR1 = 12;
public static final int HONEYCOMB_MR2 = 13;
public static final int ICE_CREAM_SANDWICH = 14;
}
public  Build() { throw new RuntimeException("Stub!"); }
public static  java.lang.String getRadioVersion() { throw new RuntimeException("Stub!"); }
public static final java.lang.String UNKNOWN = "unknown";
public static final java.lang.String ID;
public static final java.lang.String DISPLAY;
public static final java.lang.String PRODUCT;
public static final java.lang.String DEVICE;
public static final java.lang.String BOARD;
public static final java.lang.String CPU_ABI;
public static final java.lang.String CPU_ABI2;
public static final java.lang.String MANUFACTURER;
public static final java.lang.String BRAND;
public static final java.lang.String MODEL;
public static final java.lang.String BOOTLOADER;
public static final java.lang.String RADIO;
public static final java.lang.String HARDWARE;
public static final java.lang.String SERIAL;
public static final java.lang.String TYPE;
public static final java.lang.String TAGS;
public static final java.lang.String FINGERPRINT;
public static final long TIME;
public static final java.lang.String USER;
public static final java.lang.String HOST;
static { ID = null; DISPLAY = null; PRODUCT = null; DEVICE = null; BOARD = null; CPU_ABI = null; CPU_ABI2 = null; MANUFACTURER = null; BRAND = null; MODEL = null; BOOTLOADER = null; RADIO = null; HARDWARE = null; SERIAL = null; TYPE = null; TAGS = null; FINGERPRINT = null; TIME = 0; USER = null; HOST = null; }
}
